@@ -9,10 +9,11 @@ use Data::Dumper;
 use Bio::Gonzales::Matrix::IO;
 use File::Which qw/which/;
 use Bio::Gonzales::Seq::IO;
+use Bio::Gonzales::Seq;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.076'; # VERSION
+our $VERSION = '0.078'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -28,6 +29,7 @@ our $VERSION = '0.076'; # VERSION
   strand_convert
   seq_lengths
   seq_apply
+  revcom_seq_string
 );
 
 our %STRAND_CHAR_TABLE = (
@@ -86,6 +88,10 @@ sub seq_lengths {
   return \%sl;
 }
 
+sub revcom_seq_string {
+  return Bio::Gonzales::Seq::_revcom_from_string(@_);
+}
+
 sub seq_apply {
   my ( $f, $sub, $pattern ) = @_;
 
