@@ -17,12 +17,13 @@ use JSON::XS;
 use Data::Dumper;
 use Storable qw/nstore_fd fd_retrieve/;
 
-our $VERSION = '0.076'; # VERSION
+our $VERSION = '0.078'; # VERSION
 
 our %EXPORT_TAGS = (
   'all' => [
     qw(
       ndjson_iterate ndjson_hash ndjson_slurp ndjson_spew
+      ndjson_freeze ndjson_thaw
       ythaw yfreeze yslurp yspew
       jthaw jfreeze jslurp jspew
       stoslurp stospew
@@ -106,6 +107,26 @@ sub stoslurp {
   return $data;
 }
 
+sub ndjson_freeze {
+  my $entries = shift;
+  return unless (@$entries);
+  state $js = JSON::XS->new->utf8->allow_nonref;
+  return join( "\n", ( map { $js->encode($_) } @$entries ) ) . "\n";
+}
+
+sub ndjson_thaw {
+  my $data = shift;
+
+  return unless ($data);
+  my @entries = split /\n/, $data;
+
+  return unless (@entries);
+
+  state $js = JSON::XS->new->utf8->allow_nonref;
+
+  return [ map { $js->decode($_) } @entries ];
+}
+
 sub ndjson_hash {
   my $keys  = shift;
   my $files = shift;
