@@ -35,7 +35,7 @@ our %ZMODES = (
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.076'; # VERSION
+our $VERSION = '0.078'; # VERSION
 our $EXTERNAL_GZ    = which('gzip');    #which('pigz') // which('gzip');
 our $EXTERNAL_BZIP2 = which('bzip2');
 
@@ -228,7 +228,10 @@ sub is_fh {
 
   my $reftype = Scalar::Util::reftype($fh);
 
-  return 1 if ( $reftype && ( $reftype eq 'IO' or $reftype eq 'GLOB' && *{$fh}{IO} ) );
+  return 1
+    if ( $reftype
+    && ( $reftype eq 'IO' or $reftype eq 'GLOB' && *{$fh}{IO} or ( Scalar::Util::blessed($fh) && $fh->isa("IO::Handle") ) )
+    );
 
   return;
 }
